@@ -21,7 +21,7 @@ use Thrift::HttpClient;
 use Thrift::BinaryProtocol;
 use Data::Dumper;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 our $EN_DEV_TOKEN_PAGE = 
     "http://dev.evernote.com/documentation/cloud/chapters/" .
@@ -34,9 +34,11 @@ sub new {
 
     my $self = {
         evernote_host => "www.evernote.com",
-        dev_token     => undef,
-        config_file   => undef,
-        consumer_key  => undef,
+        dev_token           => undef,
+        config_file         => undef,
+        consumer_key        => undef,
+        thrift_send_timeout => 1000,
+        thrift_recv_timeout => 7500,
         %options,
     };
 
@@ -64,6 +66,8 @@ sub new {
 
     my $http_client = 
         Thrift::HttpClient->new( $user_store_uri );
+    $http_client->setSendTimeout( $self->{ thrift_send_timeout } );
+    $http_client->setRecvTimeout( $self->{ thrift_recv_timeout } );
 
     my $protocol =
         Thrift::BinaryProtocol->new( $http_client );
